@@ -20,43 +20,45 @@ from monasca_log_api_tempest.tests import base
 
 class TestLogApiConstraints(base.BaseLogsTestCase):
     @test.attr(type='gate')
-    def test_should_reject_if_content_length_missing(self):
+    def test_should_reject_if_body_is_empty(self):
         headers = base._get_headers()
-        try:
-            self.logs_client.custom_request('POST', headers, None)
-        except exceptions.UnexpectedResponseCode as urc:
-            self.assertIn('411', str(urc))  # Only possible way to detect that
-            return
+        for cli in self.logs_clients.itervalues():
+            try:
+                cli.custom_request('POST', headers, None)
+            except exceptions.UnprocessableEntity as urc:
+                self.assertEqual(422, urc.resp.status)
+                return
 
-        self.assertTrue(False, 'API should respond with 411')
+            self.assertTrue(False, 'API should respond with 411')
 
     @test.attr(type='gate')
     def test_should_reject_if_content_type_missing(self):
         headers = base._get_headers(content_type='')
-        try:
-            self.logs_client.custom_request('POST', headers, '{}')
-        except exceptions.BadRequest as urc:
-            self.assertEqual(400, urc.resp.status)
-            return
+        for cli in self.logs_clients.itervalues():
+            try:
+                cli.custom_request('POST', headers, '{}')
+            except exceptions.BadRequest as urc:
+                self.assertEqual(400, urc.resp.status)
+                return
 
-        self.assertTrue(False, 'API should respond with 400')
+            self.assertTrue(False, 'API should respond with 400')
 
     @test.attr(type='gate')
     def test_should_reject_if_wrong_content_type(self):
         headers = base._get_headers(content_type='video/3gpp')
-        try:
-            self.logs_client.custom_request('POST', headers, '{}')
-        except exceptions.InvalidContentType as urc:
-            self.assertEqual(415, urc.resp.status)
-            return
+        for cli in self.logs_clients.itervalues():
+            try:
+                cli.custom_request('POST', headers, '{}')
+            except exceptions.InvalidContentType as urc:
+                self.assertEqual(415, urc.resp.status)
+                return
 
-        self.assertTrue(False, 'API should respond with 400')
+            self.assertTrue(False, 'API should respond with 400')
 
     @test.attr(type='gate')
     def test_should_reject_too_big_message(self):
         _, message = base.generate_rejectable_message()
-        headers = base._get_headers(self.logs_client.get_headers())
-        data = base._get_data(message)
+        headers = base._get_headers(self.logs_clients["v3"].get_headers())
         # Add 'Connection: Keep-Alive' to send large message before
         # connection is closed by client. In class ClosingHttp is added
         # header 'connection:close' (which will cause closing socket before sending whole message).
@@ -64,31 +66,34 @@ class TestLogApiConstraints(base.BaseLogsTestCase):
         # Without this header set to Keep-Alive Tempest lib will try to retry connection and finally
         # raise ProtocolError.
         headers.update({'Connection': 'Keep-Alive'})
-        try:
-            self.logs_client.send_single_log(data, headers)
-        except exceptions.OverLimit as urc:
-            self.assertEqual(413, urc.resp.status)
-            return
+        for ver, cli in self.logs_clients.items():
+            data = base._get_data(message, version=ver)
+            try:
+                cli.send_single_log(data, headers)
+            except exceptions.OverLimit as urc:
+                self.assertEqual(413, urc.resp.status)
+                return
 
-        self.assertTrue(False, 'API should respond with 413')
+            self.assertTrue(False, 'API should respond with 413')
 
     @test.attr(type='gate')
     def test_should_reject_too_big_message_multiline(self):
         _, message = base.generate_rejectable_message()
         message = message.replace(' ', '\n')
-        headers = base._get_headers(self.logs_client.get_headers())
-        data = base._get_data(message)
+        headers = base._get_headers(self.logs_clients["v3"].get_headers())
         # Add Connection: Keep-Alive to send large message before
-        # connection is closed by client. In class ClosingHttp is added
+        # connection is closed by cli. In class ClosingHttp is added
         # header connection:close (which will cause closing socket before sending whole message).
         # Data are send in small TCP packages.
         # Without this header set to Keep-Alive Tempest lib will try to retry connection and finally
         # raise ProtocolError.
         headers.update({'Connection': 'Keep-Alive'})
-        try:
-            self.logs_client.send_single_log(data, headers)
-        except exceptions.OverLimit as urc:
-            self.assertEqual(413, urc.resp.status)
-            return
+        for ver, cli in self.logs_clients.items():
+            data = base._get_data(message, version=ver)
+            try:
+                cli.send_single_log(data, headers)
+            except exceptions.OverLimit as urc:
+                self.assertEqual(413, urc.resp.status)
+                return
 
-        self.assertTrue(False, 'API should respond with 413')
+            self.assertTrue(False, 'API should respond with 413')
